import React, { useEffect, useState } from 'react'
import { Table, Spin, Button, Form, Select, Input, Icon, Popconfirm } from 'antd'
import NavLink from 'umi/navlink'
import { fetch, fetchList, apis } from '@/utils/request'
import { exportExcel } from '@/utils/utils'
import CommunitySelect from '@/components/CommunitySelect'
import Search from '../components/Search'
import List from '../components/List'
import useRoomSelect from '../utils/hooks/useRoomSelect'
import NumRange from './components/NumRange'

const getListWithPoints = fetchList(apis.propUser.listWithPoints)

const Condition = props => {
  const [communityId, setCommunityId] = useState()
  const [pointsRange, setPointsRange] = useState()

  const {
    phaseId,
    setPhaseId,
    buildingId,
    setBuildingId,
    unitId,
    setUnitId,
    levelId,
    setLevelId,
    roomNoId,
    setRoomNoId,
    phaseList,
    buildingList,
    unitList,
    levelList,
    roomNoList
  } = useRoomSelect(communityId)

  const handleSearch = vals => {
    const data = {
      ...vals,
      communityId,
      phaseId,
      buildingId,
      unitId,
      levelId,
      roomNoId,
      minPoints: pointsRange[0],
      maxPoints: pointsRange[1],
    }

    if (props.onSearch) {
      props.onSearch(data)
    }
  }

  const handleReset = vals => {
    const data = {
      ...vals,
      // phaseId: undefined,
      // buildingId: undefined,
      // unitId: undefined,
      // levelId: undefined,
      // roomNoId: undefined
    }

    setPhaseId()
    setBuildingId()
    setUnitId()
    setLevelId()
    setRoomNoId()
    setPointsRange()

    if (props.onReset) {
      props.onReset(data)
    }
  }

  const handleCommunityChange = v => {
    setCommunityId(v)

    props.onCommunityChange(v)
  }

  return (
    <Search
      onSearch={handleSearch}
      onReset={handleReset}
      render={form => {
        const { getFieldDecorator } = form
        
        const handlePhaseChange = e => setPhaseId(e)
        const handleBuildingChange = e => setBuildingId(e)
        const handleUnitChange = e => setUnitId(e)
        const handleLevelChange = e => setLevelId(e)
        const handleRoomChange = e => setRoomNoId(e)
        const handlePointsRangeChange = e => setPointsRange(e)

        return (
          <>
            <Form.Item label="小区">
              <CommunitySelect value={communityId} onChange={handleCommunityChange} autoInited />
            </Form.Item>
            <Form.Item label="期/区">
              <Select value={phaseId} onChange={handlePhaseChange} style={{ minWidth: '120px' }} placeholder="期/区">
                {
                  phaseList.map(x => (<Select.Option key={x.id} value={x.id}>{x.name}</Select.Option>))
                }
              </Select>
            </Form.Item>
            <Form.Item label="楼栋">
              <Select value={buildingId} onChange={handleBuildingChange} style={{ minWidth: '120px' }} placeholder="栋">
                {
                  buildingList.map(x => (<Select.Option key={x.id} value={x.id}>{x.name}</Select.Option>))
                }
              </Select>
            </Form.Item>
            <Form.Item label="单元">
              <Select value={unitId} onChange={handleUnitChange} style={{ minWidth: '120px' }} placeholder="单元">
                {
                  unitList.map(x => (<Select.Option key={x.id} value={x.id}>{x.name}</Select.Option>))
                }
              </Select>
            </Form.Item>
            <Form.Item label="楼层">
              <Select value={levelId} onChange={handleLevelChange} style={{ minWidth: '120px' }} placeholder="楼层">
                {
                  levelList.map(x => (<Select.Option key={x.id} value={x.id}>{x.name}</Select.Option>))
                }
              </Select>
            </Form.Item>
            <Form.Item label="户号">
              <Select value={roomNoId} onChange={handleRoomChange} style={{ minWidth: '120px' }} placeholder="户号">
                {
                  roomNoList.map(x => (<Select.Option key={x.id} value={x.id}>{x.name}</Select.Option>))
                }
              </Select>
            </Form.Item>
            <Form.Item label="姓名">
            {
              getFieldDecorator('ownerName')(<Input style={{ width: '160px' }} placeholder="姓名" />)
            }
            </Form.Item>
            <Form.Item label="手机">
            {
              getFieldDecorator('phone')(<Input style={{ width: '160px' }} placeholder="手机号" />)
            }
            </Form.Item>
            <Form.Item label="身份证">
            {
              getFieldDecorator('idCard')(<Input style={{ width: '200px' }} placeholder="身份证" />)
            }
            </Form.Item>
            <Form.Item label="积分范围">
              <NumRange value={pointsRange} onChange={handlePointsRangeChange} />
            </Form.Item>            
          </>
        )
      }}
    />
  )
}

export default props => {
  const [loading, setLoading] = useState(false)
  const [listData, setListData] = useState([])
  const [pagination, setPagination] = useState({})
  const [communityId, setCommunityId] = useState()
  const [queryParams, setQueryParams] = useState({ pageNum: 1, pageSize: 10 })

  const handleSearch = (vals) => {
    setQueryParams({
      ...vals,
      pageNum: 1,
      pageSize: queryParams.pageSize,
    })
  }

  const handlePageChange = (pageNum, pageSize) => {
    setQueryParams({
      ...queryParams,      
      pageNum,
      pageSize,
    })
  }

  const handleExport = () => {
    // setLoading(true)
    // buildingInfoListExport({ data: {...queryParams, communityId, pageNum: 1, pageSize: 9999} }).then(res => {
    //   setLoading(false)
    //   exportExcel(res, "业主列表")
    // }).catch(() => setLoading(false))
  }

  useEffect(() => {
    if (communityId) {
      setLoading(true)
      getListWithPoints({...queryParams, communityId}).then(res => {
        const [list, pageInfo] = res
        setListData(list)
        setPagination(pageInfo)
        setLoading(false)
      }).catch(() => setLoading(false))
    }
  }, [queryParams, communityId])

  return (
    <div>
      <Condition onSearch={handleSearch} onReset={handleSearch} onCommunityChange={v => setCommunityId(v)} />
      <div style={{ margin: '24px 0' }}>
        <div style={{display: 'inline-block'}}>
          {/* <Button onClick={handleExport}>导出</Button> */}
        </div>
      </div>
      <List
        dataSource={listData}
        loading={loading}
        pagination={pagination}
        onPageChange={handlePageChange}
        rowKey="id"
      >
        <Table.Column
          title="姓名"
          dataIndex="ownerName"
          key="ownerName"
          render={(_, row) => {
            return row.id ? (
              <NavLink to={`/property/proprietor/detail?id=${row.id}`}>
                <Button type="link">{row.ownerName}</Button>
              </NavLink>
            ) : row.ownerName
          }}
        />
        <Table.Column title="手机号" dataIndex="phone" key="phone" />
        <Table.Column title="身份证" dataIndex="idCard" key="idCard" />
        <Table.Column
          title="性别"
          dataIndex="idCard"
          key="idCard1"
          render={(t, row) => {
            if (row.idCard) {
              const g = row.idCard.substring(16,17) - 0
              return g % 2 === 0 ? '女' : '男'
            }

            return ''
          }}
        />
        <Table.Column
          title="房间号"
          dataIndex="roomNoName"
          key="roomNoName"
          render={t => {
            return (
              <>
              {
                (t || '').split(',').map(x => <div key={x}>{x}</div>)
              }
              </>
            )
          }}
        />
        <Table.Column title="总积分" dataIndex="totalPoints" key="totalPoints" />
        
        {/* <Table.Column
          title="操作"
          key="action"
          render={(_, row) => {
            return (
              <Popconfirm
                title="确认进行删除操作?"
                onConfirm={() => handleDeleteRow(row)}
                okText="删除"
                cancelText="取消"
              >
                <Button type="link">删除</Button>
              </Popconfirm>
            )
          }}
        /> */}
      </List>
    </div>
  )
}
